@@ -81,9 +81,9 @@
  */
 
 #define VERSION		"2.5"			/* Version number... */
-#define VERS_DATE	"June 15, 1999"		/* for elm -v option */
+#define VERS_DATE	"August 31, 1999"		/* for elm -v option */
 #define WHAT_STRING	\
-	"@(#) Version 2.5, USENET supported version PL1"
+	"@(#) Version 2.5, USENET supported version PL2"
 
 #include <sys/types.h>	/* for fundamental types */
 #include <stdio.h>	/* Must get the _IOEOF flag for feof() on Convex */
