@@ -377,7 +377,7 @@ EXTERN int title_messages INIT(TRUE);	/* title message display? */
 EXTERN int use_tite INIT(TRUE);		/* use termcap/terminfo ti/te? */
 EXTERN int user_level INIT(0);		/* numeric user level */
 
-EXTERN int sortby INIT(SENT_DATE);	/* how to sort folders */
+EXTERN int sortby INIT(REVERSE SENT_DATE);	/* how to sort folders */
 EXTERN int alias_sortby INIT(NAME_SORT);/* how to sort aliases */
 
 EXTERN int clear_pages INIT(FALSE);	/* clear screen w/ builtin pgr? */
